%% LaTeX document class for PHOST Proceedings
%%
%% J. Ballot, 2008/09/01
%%
%% Based on Cool stars 19 class by Gregory A. Feiden

\NeedsTeXFormat{LaTeX2e}[1995/12/01]

\ProvidesClass{phostproc}[2018/09/01 
    v0.1 Phost proceeding document class]

\LoadClass[11pt,twocolumn, a4paper]{article}

%% Package dependencies
\RequirePackage[utf8]{inputenc}
\RequirePackage{graphicx}
\RequirePackage{latexsym}
\RequirePackage{amssymb}
\RequirePackage{natbib}
\RequirePackage{libertine}
\RequirePackage[T1]{fontenc}

%% Page dimensions 
\textwidth=180mm
\columnsep=2em
\parindent=1em
\voffset=-20.4mm
\hoffset=-10.4mm

\topmargin=0mm
\headheight=3.8mm
\headsep=12.7mm
\oddsidemargin=0mm
\evensidemargin=0mm
\parskip=.2\baselineskip
\footskip=10mm


%% Font specifications (optimize for 66 characters per line)
%%
%% Pulled from emulateapj.cls
%%
%% AV,MM, to have 64 lines per column, with textheight 25cm:
%%
\textheight=255mm  %%49\baselineskip
\textheight=\baselinestretch\textheight
\ifdim\textheight>26.7cm\textheight=26.5cm\fi

\topskip\baselineskip
\maxdepth\baselineskip

\let\tighten=\relax
\let\tightenlines=\tighten
\let\singlespace=\relax
\let\doublespace=\relax

\renewcommand\normalsize{%
   \@setfontsize\normalsize\@xpt{10.5}  %10.56
   \abovedisplayskip 2.2mm \@plus2\p@ \@minus1\p@
   \abovedisplayshortskip \z@ \@plus3\p@
   \belowdisplayshortskip 2.2mm \@plus2\p@ \@minus1\p@
   \belowdisplayskip \abovedisplayskip
   \let\@listi\@listI}
\normalsize
\renewcommand\small{%
   \@setfontsize\small\@ixpt{9.68}%
   \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus2\p@
   \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 4\p@ \@plus2\p@ \@minus2\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep}%
   \belowdisplayskip \abovedisplayskip
}
\renewcommand\footnotesize{%
   \@setfontsize\footnotesize\@viiipt{8.36}%
   \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
   \abovedisplayshortskip \z@ \@plus\p@
   \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
   \def\@listi{\leftmargin\leftmargini
               \topsep 3\p@ \@plus\p@ \@minus\p@
               \parsep 2\p@ \@plus\p@ \@minus\p@
               \itemsep \parsep}%
   \belowdisplayskip \abovedisplayskip
}
\renewcommand\scriptsize{\@setfontsize\scriptsize\@viipt\@viiipt}
\renewcommand\tiny{\@setfontsize\tiny\@vpt\@vipt}
\renewcommand\large{\@setfontsize\large\@xiipt{14}}
\renewcommand\Large{\@setfontsize\Large\@xivpt{18}}
\renewcommand\LARGE{\@setfontsize\LARGE\@xviipt{22}}
\renewcommand\huge{\@setfontsize\huge\@xxpt{25}}
\renewcommand\Huge{\@setfontsize\Huge\@xxvpt{30}}
\setlength\smallskipamount{3\p@ \@plus 1\p@ \@minus 1\p@}
\setlength\medskipamount{6\p@ \@plus 2\p@ \@minus 2\p@}
\setlength\bigskipamount{12\p@ \@plus 4\p@ \@minus 4\p@}
\setlength\headheight{12\p@}


%% Running header and footer 
\newcommand\shorttitle[1]{\gdef\@shortitle{#1}}
\newcommand\shortauthors[1]{\gdef\@shortauthors{#1}}
\newcommand\editors{J. Ballot, S. Vauclair, \& G. Vauclair}
\newcommand\publisher{Zenodo}
%\newcommand\conference[1]{\gdef\@conference{#1}}
%\newcommand\conferencedate[1]{\gdef\@conferencedate{#1}}
\newcommand\conference{PHOST ``Physics of Oscillating Stars'' -- a conference in honour of Prof. H. Shibahashi, 2-7 Sept. 2018, Banyuls-sur-mer (France)}
\newcommand\shortconference{PHOST ``Physics of Oscillating Stars'' conference}
\newcommand\conferencedate{2018}
\shorttitle{\relax}
\shortauthors{\relax}

\def\ps@csheadfoot{
    \let\@mkboth\markboth
    \def\@evenfoot{\thepage\hfil {\scriptsize \publisher, \conferencedate}}
    \def\@evenhead{\lower9mm\hbox to\textwidth{\small \hfil \@shortauthors}}
    \def\@oddfoot{{\scriptsize \publisher, \conferencedate}\hfil \rm\thepage}
    \def\@oddhead{\lower9mm\hbox to\textwidth{\small \hfil \it  \shortconference}}
}

\@twosidetrue
\ps@csheadfoot

%%
%% Title page, abstract, etc.
%%
\newcount\@naffils

\renewcommand\abstract{\relax}
\newcommand\abs[1]{\gdef \@abs{#1}}
\newcommand\affil[1]{\gdef \@affils{#1}}
\newcommand\affiliation[1]{\gdef \@affil{#1}}

\def\@maketitle{
    \vspace{-\headsep}\vspace{\headheight}
    {\footnotesize {\itshape \conference} \\
     Edited by \editors}
    
	\vskip 4.0em
	\begin{flushleft}
		{\LARGE \bfseries \sffamily \@title \par}
		\vspace{\baselineskip}
		{\large \@author}
		\par\vspace{0.5\baselineskip}
		\begingroup
		    \small
		    \@affil
		\endgroup
	\end{flushleft}
	%\hrule
	%\vspace{0.5\baselineskip}
	\begingroup
	    \begin{center}
	        \parbox{0.9\textwidth}{
	            \section*{\abstractname}
	            \small \@abs}
	    \end{center}
	\endgroup
	\vspace{0.5\baselineskip}
	%\hrule
	\vspace{\baselineskip}
}
\renewcommand\maketitle{
	\if@twocolumn
		\twocolumn[
			\par
			\begingroup
				\thispagestyle{plain}
				\@maketitle
			\endgroup
		]
	\else
		\par
		\begingroup
			\thispagestyle{plain}
			\@maketitle
		\endgroup
	\fi
}

%%
%% Sections
%%
\setcounter{secnumdepth}{3}

\def\section{
	\@startsection{section}{1}{\z@}{9pt plus 2pt minus 1pt}{4pt}{\large\bfseries\sffamily }
}

\def\subsection{\@startsection{subsection}{2}{\z@}{9pt plus 1pt minus 1pt}{4pt}%
  {\normalsize\bfseries }}

\def\subsubsection{\@startsection{subsubsection}{3}{\z@}%
  {2ex plus 1ex minus .2ex}{1ex plus .2ex}{\normalsize\itshape }}

\def\paragraph{\@startsection{paragraph}{4}{\z@}%
  {1.5ex plus 1ex minus .2ex}{-0.5\parindent}{\small\it}}

\def\subparagraph{\@startsection{subparagraph}{5}{\z@}%
  {1ex plus 1ex minus .2ex}{-0.5\parindent}{\small\it}}

\def\thesection{\@arabic{\c@section}}
\def\thesubsection{\thesection.\@arabic{\c@subsection}}
\def\thesubsubsection{\thesubsection.\@arabic{\c@subsubsection}}
\def\theparagraph{\thesubsubsection.\@arabic{\c@paragraph}}
\def\p@section        {}
\def\p@subsection     {}
\def\p@subsubsection  {}
\def\p@paragraph      {}
\def\p@subparagraph   {}

%% 
%% References
%%
\setlength{\bibsep}{0pt plus 0.3 ex}

% Some Rather Common Journal abbreviations
\newcommand{\apj}{ApJ}
\newcommand{\apjs}{ApJS}
\newcommand{\apjl}{ApJ}
\newcommand{\aj}{AJ}
\newcommand{\aap}{A\&A}
\newcommand{\aaps}{A\&AS}
\newcommand{\pasp}{PASP}
\newcommand{\pasj}{PASJ}
\newcommand{\mnras}{MNRAS}
\newcommand{\memras}{MmRAS}
\newcommand{\nat}{Nature}
\newcommand{\aapr}{A\&ARv}
\newcommand{\araa}{ARA\&A}
\newcommand{\apss}{Ap\&SS}
\newcommand{\icarus}{Icarus}
\newcommand{\an}{AN}
\newcommand{\actaa}{AcA}
\newcommand{\rmxaa}{RMxAA}
\newcommand{\memsai}{MmSAI}
\newcommand{\solphys}{SoPh}
\newcommand{\zap}{ZA}
\newcommand{\ssr}{SSRv}
\newcommand{\bain}{BAIN}
\newcommand{\azh}{AZh}
\newcommand{\pra}{PhRvA}
\newcommand{\prb}{PhRvB}
\newcommand{\prc}{PhRvC}
\newcommand{\prd}{PhRvD}
\newcommand{\pre}{PhRvE}
\newcommand{\jcaam}{JCompApMath}
\newcommand{\procspie}{Proc.~SPIE}

\endinput
